@@ -4,13 +4,23 @@ import re
 import sys
 
 from .base import ClosableResponse, EmptyResponse, Header, Method, Request, Response
+from .circuit_breaker import (
+    CircuitBreaker,
+    CircuitBreakerMetrics,
+    CircuitBreakerMetricsSnapshot,
+    CircuitState,
+    DefaultCircuitBreaker,
+    NoopCircuitBreaker,
+    RollingCircuitBreakerMetrics,
+)
 from .client import Client, DefaultClient
 from .context import get_context, set_context
 from .deadline import Deadline
 from .delays_provider import constant_delays, linear_delays
 from .metrics import NOOP_METRICS_PROVIDER, MetricsProvider, NoopMetricsProvider
 from .pipeline import (
-    LowTimeoutRequestModule,
+    BypassModule,
+    LowTimeoutModule,
     MetricsModule,
     NextModuleFunc,
     RequestModule,
@@ -62,7 +72,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "0.1.12"
+__version__ = "0.1.13"
 
 version = f"{__version__}, Python {sys.version}"
 
